Common
======

Common functions shared between the geo and the occ kernels.

Geometry
--------
.. automodule:: pygmsh.common.geometry
    :members:
    :undoc-members:
    :show-inheritance:

Bspline
-------
.. automodule:: pygmsh.common.bspline
    :members:
    :undoc-members:
    :show-inheritance:

CircleArc
---------
.. automodule:: pygmsh.common.circle_arc
    :members:
    :undoc-members:
    :show-inheritance:

EllipseArc
----------
.. automodule:: pygmsh.common.ellipse_arc
    :members:
    :undoc-members:
    :show-inheritance:

LineBase
--------
.. automodule:: pygmsh.common.line_base
    :members:
    :undoc-members:
    :show-inheritance:

CurveLoop
---------
.. automodule:: pygmsh.common.curve_loop
    :members:
    :undoc-members:
    :show-inheritance:

Line
----
.. automodule:: pygmsh.common.line
    :members:
    :undoc-members:
    :show-inheritance:

Point
-----
.. automodule:: pygmsh.common.point
    :members:
    :undoc-members:
    :show-inheritance:

Spline
------
.. automodule:: pygmsh.common.spline
    :members:
    :undoc-members:
    :show-inheritance:

SurfaceLoop
-----------
.. automodule:: pygmsh.common.surface_loop
    :members:
    :undoc-members:
    :show-inheritance:

Surface
-------
.. automodule:: pygmsh.common.surface
    :members:
    :undoc-members:
    :show-inheritance:

Volume
------
.. automodule:: pygmsh.common.volume
    :members:
    :undoc-members:
    :show-inheritance:
